import QtQuick 1.1
import com.nokia.meego 1.0

PageStackWindow {
    id: appWindow

    initialPage: mainPage

    Page {
        id: mainPage

        tools: commonTools

        Text {
            anchors {
                horizontalCenter: parent.horizontalCenter
                bottom: buttons.top
                bottomMargin: 20
            }

            color: "#ffcc00"
            text: "Power Control"
            font.pixelSize: 40
        }

        Column {
            id: buttons
            anchors.centerIn: parent
            spacing: 20

            Button{
                text: qsTr("Reboot")
                iconSource: "reboot.png"
                onClicked: {
                    if ( !deviceControl.restart() ) {
                        dialog.titleText = "Error";
                        dialog.message = deviceControl.error;
                        dialog.open();
                    }
                }
                font.pixelSize: 36
                height: 90
            }

            Button{
                text: qsTr("Shutdown")
                iconSource: "shutdown.png"
                onClicked: {
                    if ( !deviceControl.shutDown() ) {
                        dialog.titleText = "Error";
                        dialog.message = deviceControl.error;
                        dialog.open();
                    }
                }
                font.pixelSize: 36
                height: 90
            }
        }
    }

    QueryDialog {
        id: dialog;
        acceptButtonText: "OK"
        titleText: "Error"
    }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }

    QueryDialog {
        id: aboutDialog
        titleText: "Crochik Shutdown"
        message: "(C) 2012 Crochik Software<br/><a href=\"http://www.crochik.com/shutdown\">crochik.com/shutdown</a>"
        onLinkActivated: {
            console.log("Open: " + link);
            Qt.openUrlExternally(link);
            close();
        }
    }

    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: !deviceControl.isShortcutsAvailable ? qsTr("Install 1-Click") : qsTr("Remove 1-Click")
                onClicked: {
                    if ( !deviceControl.isShortcutsAvailable ) {
                        deviceControl.createShortcuts();
                        dialog.titleText = "Install 1-Click";
                        dialog.message = "Shortcuts added to list of programs.";
                    } else {
                        deviceControl.removeShortcuts();
                        dialog.titleText = "Remove 1-Click";
                        dialog.message = "Shortcuts removed from list of programs.";
                    }
                    dialog.open();
                }
            }
            MenuItem {
                text: qsTr("About")
                onClicked: {
                    aboutDialog.open();
                }
            }
        }
    }

    Component.onCompleted: {
        theme.inverted =true;
    }
}
